@@ -1,14 +1,18 @@
 #ifndef __BANNER_HEADER_INCLUDED__
 #define __BANNER_HEADER_INCLUDED__
-/* @(#) $Id: banner.h,v 1.2 2002/01/24 12:40:53 gianni Exp $ */
+/* @(#) $Id: banner.h,v 1.3 2002/02/04 08:55:47 gianni Exp $ */
 
 extern plugin_t banner_plugin;
 int banner_validate(char *conf, void **priv);
-int banner_check(char *buf, int len, void *priv);
+int banner_check(char *buf, int len, void *priv, int *errnum);
+int banner_errno(char *buf, int buflen, int err);
 
 typedef struct banner_priv {
 	char		*banner;
 	u_int32_t	len;
 }banner_priv_t, *p_banner_priv;
 
+#define BANNER_ERR_NOT_FOUND 0
+#define BANNER_ERR_TOO_SMALL 1
+
 #endif /* __BANNER_HEADER_INCLUDED__ */
