@@ -1,11 +1,12 @@
 #ifndef __HTTP_HEADER_INCLUDED__
 #define __HTTP_HEADER_INCLUDED__
-/* @(#) $Id: http.h,v 1.3 2002/01/24 12:40:53 gianni Exp $ */
+/* @(#) $Id: http.h,v 1.4 2002/02/04 08:55:47 gianni Exp $ */
 
 extern plugin_t http_plugin;
 
 int http_validate(char *conf, void **priv);
 int http_sendq(int sock, void *priv);
-int http_check(char *buf, int len, void *priv);
+int http_check(char *buf, int len, void *priv, int *errnum);
+int http_errno(char *buf, int buflen, int err);
 
 #endif /* __HTTP_HEADER_INCLUDED__ */
